@@ -112,7 +112,7 @@ import io
 
 import typer
 
-__version__ = "0.0.6"
+__version__ = "0.0.7"
 
 logo = r"""
   ___                    _
@@ -182,24 +182,78 @@ def install(names: List[str], check: bool = False):
 
     from tempfile import TemporaryDirectory
     from . import crosslink as cr
+    import trio
+    import httpx
+    from rich.console import Console
+    from io import BytesIO
+    import rich
+
+    console = Console()
 
     _intro()
 
-    @lru_cache
-    def get(name):
-        import requests
+    async def get(name, version, results, progress):
 
-        r = requests.get(f"https://pydocs.github.io/pkg/{name}.zip")
-        return r.content
+        buf = BytesIO()
 
-    for name in names:
-        data = get(name)
-        print(len(data))
+        client = httpx.AsyncClient()
 
-        zf = zipfile.ZipFile(io.BytesIO(data), "r")
-        with TemporaryDirectory() as d:
-            zf.extractall(d)
-            cr.main(next(iter([x for x in Path(d).iterdir() if x.is_dir()])), check)
+        async with client.stream(
+            "GET", f"https://pydocs.github.io/pkg/{name}-{version}.zip"
+        ) as response:
+            total = int(response.headers["Content-Length"])
+
+            download_task = progress.add_task(f"Download {name} {version}", total=total)
+            async for chunk in response.aiter_bytes():
+                buf.write(chunk)
+                progress.update(download_task, completed=response.num_bytes_downloaded)
+
+            if response.status_code != 200:
+                results[(name, version)] = None
+            else:
+                buf.seek(0)
+                results[(name, version)] = buf.read()
+
+    async def m_():
+        results = {}
+        with rich.progress.Progress(
+            "{task.description}",
+            "[progress.percentage]{task.percentage:>3.0f}%",
+            rich.progress.BarColumn(bar_width=None),
+            rich.progress.DownloadColumn(),
+            rich.progress.TransferSpeedColumn(),
+        ) as progress:
+            async with trio.open_nursery() as nursery:
+                for name in names:
+
+                    if "==" in name:
+                        name, version = name.split("==")
+                    else:
+                        try:
+                            mod = __import__(name)
+                            version = mod.__version__
+                            print(
+                                f"Autodetecting version for {name}:{version}, use {name}==<version> if incorrect."
+                            )
+                        except Exception:
+                            print(
+                                f"Could not detect version for {name} use {name}==<version> if incorrect."
+                            )
+                            continue
+                    # with console.status(f"Downloading documentation for {name}") as status:
+                    nursery.start_soon(get, name, version, results, progress)
+        return results
+
+    datas = trio.run(m_)
+    for (name, version), data in datas.items():
+        if data is not None:
+            # print("Downloaded", name, version, len(data) // 1024, "kb")
+            zf = zipfile.ZipFile(io.BytesIO(data), "r")
+            with TemporaryDirectory() as d:
+                zf.extractall(d)
+                cr.main(next(iter([x for x in Path(d).iterdir() if x.is_dir()])), check)
+        else:
+            print("Could not find docs for ", name, version)
     cr.relink()
 
 
