@@ -48,6 +48,7 @@ from there import syslogprint as LOG
 import json
 import pathlib
 
+
 class Link:
     def __init__(self, attr, text, cb):
         self.attr = attr
@@ -67,6 +68,8 @@ class TextWithLink(urwid.Text):
         >>> Edit("? ","yes").get_cursor_coords((10,))
         (5, 0)
         """
+        from there import syslogprint as LOG
+
         if not self._focusable:
             return None
 
@@ -92,6 +95,10 @@ class TextWithLink(urwid.Text):
                         for it in item:
                             assert isinstance(it, str)
                         current_len += sum([len(x) for x in item])
+                    elif isinstance(item, str):
+                        current_len += len(item)
+                    else:
+                        assert False, (repr(item), repr(self.markup))
 
                 elif isinstance(item, str):
                     current_len += len(item)
@@ -289,9 +296,17 @@ class Renderer:
 
         return method(obj)
 
+    def render_Math(self, d):
+        cont = "".join(d.value)
+        from flatlatex import converter
+
+        c = converter()
+        return ("math", c.convert(cont))
+
     def render_Directive(self, d):
         cont = "".join(d.value)
         if d.role == "math":
+            assert False
             from flatlatex import converter
 
             c = converter()
@@ -302,6 +317,17 @@ class Renderer:
     def render_Words(self, words):
         return words.value
 
+    def render_Example(self, ex):
+        acc = []
+        for line in ex.lines:
+            acc.append(Text(line._line))
+        a = urwid.Pile(acc)
+        acc = []
+        for line in ex.ind:
+            acc.append(Text(line._line))
+        b = urwid.Padding(urwid.Pile(acc), left=4)
+        return urwid.Pile([a, b])
+
     def render_Link(self, link):
         if link.reference.kind == "local":
             return ("local", link.value)
@@ -313,14 +339,28 @@ class Renderer:
         )
 
     def render_Admonition(self, adm):
+        kind = adm.kind
+        title = (f"{kind} : {adm.title}",)
+        if kind == "versionchanged":
+            title = "Changed in Version " + adm.title
+        if kind == "versionadded":
+            title = "Added in Version " + adm.title
+        if kind == "deprecated":
+            title = "Deprecated since " + adm.title
         return urwid.Padding(
             urwid.LineBox(
                 urwid.Pile([self.render(c) for c in adm.children]),
-                title=f"{adm.kind} : {adm.title}",
+                title=title,
                 title_align="left",
             ),
         )
 
+    def render_BlockMath(self, math):
+        from flatlatex import converter
+
+        c = converter()
+        return urwid.Padding(urwid.Text(("math", c.convert(math.value))), left=2)
+
     def render_BlockDirective(self, directive):
         if directive.directive_name == "note":
             return urwid.Padding(
@@ -332,11 +372,14 @@ class Renderer:
             )
 
         elif directive.directive_name == "math":
+            assert False
             args0 = [a for a in directive.args0 if a]
             inner = directive.inner
             content = " ".join(directive.args0)
             if content:
-                assert not inner, (directive.args0, inner)
+                if inner:
+                    assert len(inner.children) == 1
+                    content = content + inner.children[0].value
             else:
                 assert len(inner.children) == 1
 
@@ -424,6 +467,13 @@ class Renderer:
             p.extend(res)
         return urwid.Pile(p)
 
+    def render_EnumeratedList(self, elist):
+        p = [blank]
+        for i, c in enumerate(elist.children, start=1):
+            res = self.render(c)
+            p.extend([urwid.Columns([(3, urwid.Text(f"{i}.")), res])])
+        return urwid.Pile(p)
+
     def render_DefListItem(self, item):
         return [
             self.render(item.dt),
@@ -484,7 +534,12 @@ class Renderer:
                 type_ = e.type
                 maybe_link = e.link
                 if maybe_link.__class__.__name__ == "Link":
-                    yield ("pyg-" + str(type_), maybe_link.value)
+                    assert isinstance(maybe_link.reference, RefInfo)
+                    yield Link(
+                        "pyg-" + str(type_),
+                        maybe_link.value,
+                        (lambda m: (lambda: self.cb(m.reference)))(maybe_link),
+                    )
                 else:
                     if maybe_link == "\n":
                         yield (None, "\n")
@@ -544,6 +599,8 @@ class Renderer:
                 ),
             ]
         )
+
+
 def main(qualname: str):
     if not isinstance(qualname, str):
         from types import ModuleType
@@ -557,9 +614,6 @@ def main(qualname: str):
     # data = json.loads(file_path.read_text())
     # data
 
-
-
-
     def gen_content(blob, frame):
         R = Renderer(frame, walk, gen_content, stack)
         doc = []
@@ -623,7 +677,6 @@ def main(qualname: str):
 
     stack = []
 
-
     walk = urwid.SimpleListWalker([])
     listbox = urwid.ListBox(walk)
     frame = urwid.Frame(urwid.AttrWrap(listbox, "body"))  # , header=header)
@@ -700,6 +753,7 @@ def main(qualname: str):
     else:
         screen = urwid.raw_display.Screen()
     found = True
+
     def unhandled(key):
         nonlocal found
         if key == "?":
