@@ -197,7 +197,7 @@ class Verbatim(Node):
         if len(tokens) < 5:
             return None
         if (tokens[0], tokens[1]) == ("`", "`") and tokens[2].strip():
-            for i, t in enumerate(tokens[2:-2]):
+            for i, t in enumerate(tokens[2:]):
                 if t == "`" and tokens[i + 2] == "`":
                     return cls(acc), tokens[i + 4 :]
                 else:
@@ -346,6 +346,10 @@ class Directive(Node):
         return "<Directive " + prefix + "`" + "".join(self.value) + "`>"
 
 
+class BlockMath(Node):
+    value: str
+
+
 class Math(Node):
     value: List[str]  # list of tokens not list of lines.
 
@@ -466,6 +470,7 @@ class Section(Node):
             Paragraph,
             DefList,
             BlockDirective,
+            BlockMath,
             Example,
             BlockVerbatim,
             Param,
@@ -528,6 +533,7 @@ class Param(Node):
             DefListItem,
             DefList,
             BlockDirective,
+            BlockMath,
             Example,
             BlockVerbatim,
             Admonition,
@@ -719,7 +725,7 @@ class Paragraph(Node):
 
         rest = tokens
         acc = []
-        parser = FirstCombinator([Directive, Verbatim, Word])
+        parser = FirstCombinator([Verbatim, Directive, Word])
         while rest:
             parsed, rest = parser.parse(rest)
             acc.append(parsed)
